//
//  ManualProfile.swift
//  SwiftDMCPExample6DOF
//
//  Created by Malcolm Anderson on 6/28/21.
//

import Foundation

struct ManualProfile: MotionProfile {
    var name: String = "Manual"
    var icon = "slider.horizontal.3"
    
    var description: String = "Allows the user to manually set values for each of the six degrees of freedom"
    
    var parameters: [MotionProfileParameter] = [
        MotionProfileParameter(name: "X Position", minimumValue: -3.0, maximumValue: 3.0, defaultValue: 0.0),
        MotionProfileParameter(name: "Y Position", minimumValue: -3.0, maximumValue: 3.0, defaultValue: 0.0),
        MotionProfileParameter(name: "Z Position", minimumValue: -3.0, maximumValue: 3.0, defaultValue: 0.0),
        
        MotionProfileParameter(name: "Yaw", minimumValue: -60.0, maximumValue: 60.0, defaultValue: 0.0),
        MotionProfileParameter(name: "Pitch", minimumValue: -60.0, maximumValue: 60.0, defaultValue: 0.0),
        MotionProfileParameter(name: "Roll", minimumValue: -60.0, maximumValue: 60.0, defaultValue: 0.0),
    ]
    
    func evaluate(_ t: Double, withParameterValues parameterValues: [Double] = [0,0,0,0,0,0]) -> MotionProfileOutput {
        let x = parameterValues[0]
        let y = parameterValues[1]
        let z = parameterValues[2]
        let yaw = parameterValues[3]
        let pitch = parameterValues[4]
        let roll = parameterValues[5]
        
        var output = MotionProfileOutput()
        output.x = x
        output.y = y
        output.z = z
        output.yaw = yaw
        output.pitch = pitch
        output.roll = roll
        
        return output
    }
}
