//
//  MoveInCirclesProfile.swift
//  SwiftDMCPExample6DOF
//
//  Created by Malcolm Anderson on 6/28/21.
//

import Foundation

struct MoveInCirclesProfile: MotionProfile {
    var name: String = "Move in Circles"
    var icon = "arrow.counterclockwise"
    
    var description: String = "Slides the 6DOF platform around in circles"
    
    var strength: Double = 0.0
    
    var parameters: [MotionProfileParameter] = [
        MotionProfileParameter(name: "Strength", minimumValue: 0.1, maximumValue: 0.6, defaultValue: 0.5),
        MotionProfileParameter(name: "Frequency", minimumValue: 0.5, maximumValue: 5.0, defaultValue: 1.0)
    ]
    
    func evaluate(_ t: Double, withParameterValues parameterValues: [Double] = [1.0, 1.0]) -> MotionProfileOutput {
        let strength = parameterValues[0]
        let frequency = parameterValues[1]

        let x = strength * cos(frequency * t)
        let y = strength * sin(frequency * t)
        
        var output = MotionProfileOutput()
        output.x = x
        output.y = y
        
        return output
    }
}
