//
//  VerticalBounceProfile.swift
//  SwiftDMCPExample6DOF
//
//  Created by Malcolm Anderson on 6/28/21.
//

import Foundation

struct VerticalBounceProfile: MotionProfile {
    var name: String = "Vertical Bounce"
    var icon = "rectangle.expand.vertical"
    
    var description: String = "Bounces the 6DOF platform up and down in a cyclic motion"
    
    var strength: Double = 0.0
    
    var parameters: [MotionProfileParameter] = [
        MotionProfileParameter(name: "Strength", minimumValue: 0.1, maximumValue: 0.6, defaultValue: 0.5),
        MotionProfileParameter(name: "Frequency", minimumValue: 0.5, maximumValue: 5.0, defaultValue: 1.0)
    ]
    
    func evaluate(_ t: Double, withParameterValues parameterValues: [Double] = [1.0, 1.0]) -> MotionProfileOutput {
        let strength = parameterValues[0]
        let frequency = parameterValues[1]

        let z = strength * sin(frequency * t)
        
        var output = MotionProfileOutput()
        output.z = z
        
        return output
    }
}
