//
//  ContentView.swift
//  SwiftDMCPExample6DOF
//
//  Created by Malcolm Anderson on 6/8/21.
//

import SwiftUI

/**
 Main tab view of the app, which allows the user to view profiles, settings, or background information.
 */
struct ContentView: View {
    @EnvironmentObject var manager: Manager
    @State var isActive: Bool = false
    @State var selectedView: Int = 1
    
    var body: some View {
        TabView(selection: self.$manager.currentIndex) {
            ProfilesView()
                .tabItem {
                    Label("Profiles", systemImage: "film")
                }
                .tag(1)
            SettingsView()
                .tabItem {
                    Label("Settings", systemImage: "gear")
                }
                .tag(2)
            AboutView()
                .tabItem {
                    Label("About", systemImage: "info.circle")
                }
                .tag(3)
        }

        // Global alert box for when errors occur and need to be shown to the user
        .alert(item: self.$manager.error) { error in
            Alert(title: Text("Error occurred"), message: Text("\(error.string)"), dismissButton: .default(Text("OK")))
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView().environmentObject(Manager())
    }
}
