//
//  IconListItemView.swift
//  SwiftDMCPExample6DOF
//
//  Created by Malcolm Anderson on 6/29/21.
//

import SwiftUI

/**
 Provides a horizontal list item that resembles those found in iOS Settings.
 */
struct IconListItemView<Content: View>: View {
    @State var title: String = "Setting Item"
    @State var secondaryText: String = ""
    @State var icon: String = "wifi"
    @State var color: Color = .red
    
    var destinationView: Content
    
    
    var body: some View {
        NavigationLink(destination: self.destinationView) {
            HStack {
                Label {
                    Text(self.title)
                } icon: {
                    ZStack {
                        RoundedRectangle(cornerRadius: 7.0)
                            .aspectRatio(1.0, contentMode: .fit)
                            .foregroundColor(self.color)
                        Image(systemName: self.icon)
                            .foregroundColor(.white)
                    }
                }
                
                if self.secondaryText != "" {
                    Spacer()
                    Text(self.secondaryText)
                        .foregroundColor(.secondary)
                }
            }
        }
    }
}

struct IconListItemView_Previews: PreviewProvider {
    static var previews: some View {
        IconListItemView(destinationView: Text("haha"))
    }
}
