//
//  SingleAxisLabelView.swift
//  SwiftDMCPExample6DOF
//
//  Created by Malcolm Anderson on 6/8/21.
//

import SwiftUI

/**
 Displays the name and current value of a single axis item.
 */
struct SingleAxisLabelView: View {
    @EnvironmentObject var manager: Manager
    
    @State var title: String = "Something"
    @State var suffix: String = ""
    @State var color: Color = .blue
    @Binding var value: Double
    
    var body: some View {
        VStack {
            Text(self.title)
                .font(.system(.title, design: .rounded))
            Text(String(format: "%2.02f\(self.suffix)", self.value))
                .fixedSize(horizontal: false, vertical: true)
                .frame(maxWidth: .infinity)
                .font(self.bigFont)
                
                .animation(.default)
        }
        .animation(.default)
        .opacity(self.manager.connected && self.manager.sendToRMC ? 1.0 : 0.7)
        .frame(width: 160)
        .foregroundColor(self.color)

    }
    
    var bigFont: Font {
        return Font
            .system(.largeTitle, design: .rounded)
                .bold()
                .monospacedDigit()
    }
    
    var smallFont: Font {
        return Font
            .system(.title2, design: .rounded)
                .monospacedDigit()
    }
}
